==> jc-1.4.0.tar.gz: soot/Timer.h <==
// public class soot.Timer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 768d5b31af70ddeb soot_Timer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Timer_H_
#define _JC_soot_Timer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_Timer$sub_refs	_jc_soot_Timer$sub_refs;
typedef struct _jc_soot_Timer$sub_nonrefs	_jc_soot_Timer$sub_nonrefs;
typedef struct _jc_soot_Timer$refs	_jc_soot_Timer$refs;
typedef struct _jc_soot_Timer$nonrefs	_jc_soot_Timer$nonrefs;
typedef struct _jc_soot_Timer$object	_jc_soot_Timer$object;

typedef const struct _jc_soot_Timer$vmethods	_jc_soot_Timer$vmethods;
typedef const struct _jc_soot_Timer$vtable	_jc_soot_Timer$vtable;
typedef const struct _jc_soot_Timer$vtype	_jc_soot_Timer$vtype;

// Constructors
extern void _jc_soot_Timer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_Timer$object *);
extern void _jc_soot_Timer$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_Timer$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_Timer$method$end$d5ec7c830865cdfd(_jc_env *, struct _jc_soot_Timer$object *);
extern jlong _jc_soot_Timer$method$getTime$5fabbaa41130db0f(_jc_env *, struct _jc_soot_Timer$object *);
extern void _jc_soot_Timer$method$start$cc0394c28c2e6109(_jc_env *, struct _jc_soot_Timer$object *);
extern struct _jc_java_lang_String$object *_jc_soot_Timer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_Timer$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_Timer$method_info$end$d5ec7c830865cdfd;
extern _jc_method _jc_soot_Timer$method_info$getTime$5fabbaa41130db0f;
extern _jc_method _jc_soot_Timer$method_info$start$cc0394c28c2e6109;
extern _jc_method _jc_soot_Timer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_Timer$vmethods {
	void	(*end$d5ec7c830865cdfd)(_jc_env *, struct _jc_soot_Timer$object *);
	jlong	(*getTime$5fabbaa41130db0f)(_jc_env *, struct _jc_soot_Timer$object *);
	void	(*start$cc0394c28c2e6109)(_jc_env *, struct _jc_soot_Timer$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_Timer$object *);
};

// Vtable
struct _jc_soot_Timer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Timer$vmethods	soot_Timer;
};

// Vtype
struct _jc_soot_Timer$vtype {
	_jc_type			type;
	_jc_soot_Timer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Timer$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_Timer$refs {
    _jc_soot_Timer$sub_refs	soot_Timer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Timer$sub_nonrefs {
	jlong	duration;
	jlong	startTime;
	jboolean	hasStarted;
};

// Non-reference instance fields (object)
struct _jc_soot_Timer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Timer$sub_nonrefs	soot_Timer;
};

// Object instance structure
struct _jc_soot_Timer$object {
	_jc_soot_Timer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Timer$vtype	*vtype;
	_jc_soot_Timer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Timer$vtype _jc_soot_Timer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Timer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Timer$class_object;

#endif	/* _JC_soot_Timer_H_ */

==> jc-1.4.6.tar.gz: soot/Timer.h <==
// public class soot.Timer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 768d5b31af70ddeb soot_Timer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Timer_H_
#define _JC_soot_Timer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_Timer$sub_refs	_jc_soot_Timer$sub_refs;
typedef struct _jc_soot_Timer$sub_nonrefs	_jc_soot_Timer$sub_nonrefs;
typedef struct _jc_soot_Timer$refs	_jc_soot_Timer$refs;
typedef struct _jc_soot_Timer$nonrefs	_jc_soot_Timer$nonrefs;
typedef struct _jc_soot_Timer$object	_jc_soot_Timer$object;

typedef const struct _jc_soot_Timer$vmethods	_jc_soot_Timer$vmethods;
typedef const struct _jc_soot_Timer$vtable	_jc_soot_Timer$vtable;
typedef const struct _jc_soot_Timer$vtype	_jc_soot_Timer$vtype;

// Constructors
extern void _jc_soot_Timer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_Timer$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_Timer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_Timer$method$end$d5ec7c830865cdfd(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
extern jlong _jc_soot_Timer$method$getTime$5fabbaa41130db0f(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_Timer$method$start$cc0394c28c2e6109(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_Timer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_Timer$method_info$end$d5ec7c830865cdfd;
extern _jc_method _jc_soot_Timer$method_info$getTime$5fabbaa41130db0f;
extern _jc_method _jc_soot_Timer$method_info$start$cc0394c28c2e6109;
extern _jc_method _jc_soot_Timer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_Timer$vmethods {
	void	(*end$d5ec7c830865cdfd)(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
	jlong	(*getTime$5fabbaa41130db0f)(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
	void	(*start$cc0394c28c2e6109)(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_Timer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_Timer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Timer$vmethods	soot_Timer;
};

// Vtype
struct _jc_soot_Timer$vtype {
	_jc_type			type;
	_jc_soot_Timer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Timer$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_Timer$refs {
    _jc_soot_Timer$sub_refs	soot_Timer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Timer$sub_nonrefs {
	jlong	duration;
	jlong	startTime;
	jboolean	hasStarted;
};

// Non-reference instance fields (object)
struct _jc_soot_Timer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Timer$sub_nonrefs	soot_Timer;
};

// Object instance structure
struct _jc_soot_Timer$object {
	_jc_soot_Timer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Timer$vtype	*vtype;
	_jc_soot_Timer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Timer$vtype _jc_soot_Timer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Timer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Timer$class_object;

#endif	/* _JC_soot_Timer_H_ */
